ValidationRuleBuilder class

Builder allowing to combine multiple validation rules

Constructors

ValidationRuleBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRule(ValidationRule rule) ValidationRuleBuilder
Adds a rule to the list
addRules(List<ValidationRule> rules) ValidationRuleBuilder
Adds multiple rules to the list
build() ValidationRule
Creates a composite rule that combines all added rules
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited